@@ -19,7 +19,9 @@
 #' 
 #' @param datadea The data, including \code{n} DMUs, \code{m} inputs and \code{s} outputs.
 #' @param dmu_eval A numeric vector containing which DMUs have to be evaluated.
+#' If \code{NULL} (default), all DMUs are considered.
 #' @param dmu_ref A numeric vector containing which DMUs are the evaluation reference set.
+#' If \code{NULL} (default), all DMUs are considered.
 #' @param orientation This parameter is either \code{NULL} (default) or a string, equal to
 #'                    "io" (input-oriented) or "oo" (output-oriented). It is used to modify the weight slacks. 
 #'                    If input-oriented, \code{weight_slack_o} are taken 0.
@@ -149,7 +151,7 @@ model_additive <-
   
   if (is.null(dmu_eval)) {
     dmu_eval <- 1:nd
-  } else if (all(dmu_eval %in% (1:nd)) == FALSE) {
+  } else if (!all(dmu_eval %in% (1:nd))) {
     stop("Invalid set of DMUs to be evaluated (dmu_eval).")
   }
   names(dmu_eval) <- dmunames[dmu_eval]
@@ -157,7 +159,7 @@ model_additive <-
   
   if (is.null(dmu_ref)) {
     dmu_ref <- 1:nd
-  } else if (all(dmu_ref %in% (1:nd)) == FALSE) {
+  } else if (!all(dmu_ref %in% (1:nd))) {
     stop("Invalid set of reference DMUs (dmu_ref).")
   }
   names(dmu_ref) <- dmunames[dmu_ref]
@@ -324,6 +326,21 @@ model_additive <-
     
   }
   
+  # Checking if a DMU is in its own reference set (when rts = "grs")
+  if (rts == "grs") {
+    eps <- 1e-6
+    for (i in 1:nde) {
+      j <- which(dmu_ref == dmu_eval[i])
+      if (length(j) == 1) {
+        kk <- DMU[[i]]$lambda[j]
+        kk2 <- sum(DMU[[i]]$lambda[-j])
+        if ((kk > eps) && (kk2 > eps)) {
+          warning(paste("Under generalized returns to scale,", dmunames[dmu_eval[i]], "appears in its own reference set."))
+        }
+      }
+    }
+  }
+  
   deaOutput <- list(modelname = "additive",
                     rts = rts,
                     L = L,
