@@ -13,11 +13,15 @@
 #'                   U = 1,
 #'                   compute_target = TRUE,
 #'                   compute_rho = FALSE,
+#'                   kaizen = FALSE,
+#'                   silent = FALSE,
 #'                   returnlp = FALSE)
 #' 
 #' @param datadea The data, including DMUs, inputs and outputs.
 #' @param dmu_eval A numeric vector containing which DMUs have to be evaluated.
+#' If \code{NULL} (default), all DMUs are considered.
 #' @param dmu_ref A numeric vector containing which DMUs are the evaluation reference set.
+#' If \code{NULL} (default), all DMUs are considered.
 #' @param weight_input A value, vector of length \code{m}, or matrix \code{m} x \code{ne} (where \code{ne} is the lenght of \code{dmu_eval})
 #'                     with weights to inputs corresponding to the relative importance of items.
 #' @param weight_output A value, vector of length \code{m}, or matrix \code{m} x \code{ne} (where \code{ne} is the lenght of \code{dmu_eval})
@@ -28,7 +32,11 @@
 #' @param L Lower bound for the generalized returns to scale (grs).
 #' @param U Upper bound for the generalized returns to scale (grs).
 #' @param compute_target Logical. If it is \code{TRUE}, it computes targets, superslacks (\code{t_input} and \code{t_output}) and slacks.
-#' @param compute_rho Logical. If it is \code{TRUE}, it computes \code{rho} applying \code{model_sbmeff} to the DMU (\code{project_input}, \code{project_output}).
+#' @param compute_rho Logical. If it is \code{TRUE}, it computes the SBM efficiency score (applying \code{model_sbmeff})
+#' of the DMU (\code{project_input}, \code{project_output}).
+#' @param kaizen Logical. If \code{TRUE}, the kaizen version of SBM (Tone 2010), also known as SBM-Max, is computed for the efficiency score
+#' of the DMU (\code{project_input}, \code{project_output}).
+#' @param silent Logical. If \code{FALSE} (default) it prints all the messages from function \code{maximal_friends}.
 #' @param returnlp Logical. If it is \code{TRUE}, it returns the linear problems (objective function and constraints).
 #'   
 #' @author 
@@ -46,7 +54,9 @@
 #' @references 
 #' 
 #' Tone, K. (2002). "A slacks-based measure of super-efficiency in data envelopment analysis", European Journal of Operational Research, 143, 32-41. \url{https://doi.org/10.1016/S0377-2217(01)00324-1}  
-#' 
+#'
+#' Tone, K. (2010). "Variations on the theme of slacks-based measure of efficiency in DEA", European Journal of Operational Research, 200, 901-907. \url{https://doi.org/10.1016/j.ejor.2009.01.027}
+#'   
 #' Cooper, W.W.; Seiford, L.M.; Tone, K. (2007). Data Envelopment Analysis. A Comprehensive Text with Models, Applications, References and DEA-Solver Software. 2nd Edition. Springer, New York. \url{https://doi.org/10.1007/978-0-387-45283-8}
 #' 
 #' @examples 
@@ -80,6 +90,8 @@ model_sbmsupereff <-
            U = 1,
            compute_target = TRUE,
            compute_rho = FALSE,
+           kaizen = FALSE,
+           silent = FALSE,
            returnlp = FALSE) {
     
   # Cheking whether datadea is of class "deadata" or not...  
@@ -130,7 +142,7 @@ model_sbmsupereff <-
   
   if (is.null(dmu_eval)) {
     dmu_eval <- 1:nd
-  } else if (all(dmu_eval %in% (1:nd)) == FALSE) {
+  } else if (!all(dmu_eval %in% (1:nd))) {
     stop("Invalid set of DMUs to be evaluated (dmu_eval).")
   }
   names(dmu_eval) <- dmunames[dmu_eval]
@@ -138,7 +150,7 @@ model_sbmsupereff <-
   
   if (is.null(dmu_ref)) {
     dmu_ref <- 1:nd
-  } else if (all(dmu_ref %in% (1:nd)) == FALSE) {
+  } else if (!all(dmu_ref %in% (1:nd))) {
     stop("Invalid set of reference DMUs (dmu_ref).")
   }
   names(dmu_ref) <- dmunames[dmu_ref]
@@ -225,7 +237,7 @@ model_sbmsupereff <-
   slack_input <- NULL
   slack_output <- NULL
   rho <- NULL
-  mix <- NULL
+  gamma <- NULL
     
   DMU <- vector(mode = "list", length = nde)
   names(DMU) <- dmunames[dmu_eval]
@@ -349,24 +361,23 @@ model_sbmsupereff <-
         
         if (compute_rho) {
           
-          dmunames2 <- c(dmunames[ii], dmunames[-ii])
-          input2 <- cbind(matrix(project_input, nrow = ni, ncol = 1),
-                          matrix(input[, -ii], nrow = ni))
-          rownames(input2) <- inputnames
-          colnames(input2) <- dmunames2
-          output2 <- cbind(matrix(project_output, nrow = no, ncol = 1),
-                           matrix(output[, -ii], nrow = no))
-          rownames(output2) <- outputnames
-          colnames(output2) <- dmunames2
+          input2 <- input
+          input2[, ii] <- project_input
+          output2 <- output
+          output2[, ii] <- project_output
           datadea2 <- structure(list(input = input2,
                                      output = output2,
-                                     dmunames = dmunames2,
+                                     dmunames = dmunames,
                                      nc_inputs = nc_inputs,
                                      nc_outputs = nc_outputs),
                                 class = "deadata")
           
+          if ((rts == "grs") && kaizen) {
+            stop("Kaizen is not available for generalized returns to scale.")
+          }
+          
           deasol <- model_sbmeff(datadea = datadea2,
-                                 dmu_eval = 1,
+                                 dmu_eval = ii,
                                  dmu_ref = dmu_ref,
                                  weight_input = weight_input[, i],
                                  weight_output = weight_output[, i],
@@ -374,10 +385,12 @@ model_sbmsupereff <-
                                  rts = rts,
                                  L = L,
                                  U = U,
+                                 kaizen = kaizen,
+                                 silent = silent,
                                  compute_target = FALSE)
           
           rho <- deasol$DMU[[1]]$efficiency
-          mix <- rho + delta - 1
+          gamma <- rho * delta
           
         }
         
@@ -397,15 +410,15 @@ model_sbmsupereff <-
         }
         if (compute_rho) {
           rho <- NA
-          mix <- NA
+          gamma <- NA
         }
         
       }
       
       DMU[[i]] <- list(delta = delta,
                        rho = rho,
-                       mix = mix,
-                       t = t,
+                       gamma = gamma,
+                       kaizen = kaizen,
                        lambda = lambda,
                        project_input = project_input, project_output = project_output,
                        target_input = target_input, target_output = target_output,
